@@ -30,6 +30,8 @@ pub enum HealthCheckError {
     SerdeError(#[from] serde_json::Error),
     #[error(transparent)]
     FromUtf8Error(#[from] std::string::FromUtf8Error),
+    #[error(transparent)]
+    ParseIntError(#[from] std::num::ParseIntError),
 }
 
 #[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
@@ -73,7 +75,7 @@ impl HealthCheck {
         let output = Command::new("systemctl").args(args).output()?;
         let status = String::from_utf8_lossy(&output.stdout);
         info!("firstbook_ok() substate={} status={}", substate, status);
-        Ok(substate == "exited" && status == "0")
+        Ok(substate == "exited" && status.parse::<i32>()? == 0)
     }
 
     pub fn list_units() -> Result<Vec<UnitState>, HealthCheckError> {
